@@ -6,14 +6,14 @@
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "netbsd2.0.2"
+#define HOST_OS "netbsd2.1"
 #define HOST_OS_NAME "netbsd"
-#define HOST_OS_VERSION "2.0.2"
+#define HOST_OS_VERSION "2.1"
 #define HOST_ARCH "i386"
 #define DISTRO_NAME "none"
-#define HOST_NAME "a-netbsd20.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-netbsd21"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu May 11 11:28:19 EDT 2006"
+#define CONFIG_DATE "Fri Dec  2 15:14:18 EST 2005"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
@@ -34,7 +34,7 @@
 #ifdef __cplusplus
 #include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "2.0.2"
+#define HOST_HEADER_VERSION "2.1"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBRT 1
@@ -233,7 +233,6 @@
 #define HAVE_TIME_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_HESIOD_H 1
-#define NEW_DBM_H "ndbm.h"
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_netbsd1_4.h"
 #define HAVE_STRUCT_NFS_ARGS 1
@@ -306,14 +305,19 @@
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_SUN 1
+#define HAVE_WAITPID 1
 #define HAVE_MAP_EXEC 1
+#define HAVE_HES_INIT 1
 #define HAVE_MAP_HESIOD 1
-#define HAVE_DBM_OPEN 1
-#define HAVE_MAP_NDBM 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_MFS 1
@@ -336,7 +340,7 @@
 #define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS MOUNT_NFS
 #define MOUNT_TYPE_NFS3 MOUNT_NFS3
-#define MOUNT_TYPE_UFS MOUNT_UFS
+#define MOUNT_TYPE_UFS MOUNT_FFS
 #define MOUNT_TYPE_CDFS MOUNT_CD9660
 #define MOUNT_TYPE_PCFS MOUNT_MSDOS
 #define MOUNT_TYPE_MFS MOUNT_MFS
@@ -392,3 +396,4 @@
 #define MNT2_PCFS_OPT_NOWIN95 0x4
 #define MNT2_PCFS_OPT_SHORTNAME 0x1
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_GETMNTINFO 1
